#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Mindmap to Github Markdown."""
from freeplane_tools.base import BaseNode, MindMapInterface
from freeplane_tools.mm import Mindmap
import re


class GithubNode(BaseNode):
    """Github Node Class."""

    @property
    def _toc_name(self):
        return re.sub("[^a-zA-Z0-9]", "-", self.text).lower() + "-"

    def format(self):
        if self.list_depth >= 0:
            return self.list_format()
        lines = []
        title_pad = "#" * (self.depth + 1)
        title = self.text
        img_link = ""
        if self.link and self.has_img_link:
            img_link = self.img_link()
        elif self.link:
            title = f"{self.text} [\[link\]]({self.link})"
        title = f"{title_pad} {title} [&#8593;](#toc)"
        lines.append(title)
        lines.append(self.note)
        if img_link:
            lines.append(img_link)
        return "\n".join(lines)


class MindMapInterface(object):
    # Needs to be defined in subclass
    node = None

    def __init__(self, srcfile):
        self.mm = Mindmap(srcfile)
        if self.__class__.node is None:
            raise RuntimeError(f"Please define {__class__}.node")

    def _iternodes(self):
        for obj in self.mm.iternodes():
            yield self.__class__.node(obj)

    def _toc(self):
        return "\n".join(n.toc_entry for n in self._iternodes() if n.toc_entry)

    def _body(self):
        return "\n".join(n.format() for n in self._iternodes())

    def get_document(self):
        txt = "\n".join(
            [
                '<a name="toc"></a>',
                "# TOC",
                self._toc(),
                "",
                "",
                self._body(),
                "",
            ]
        )
        return txt

    def write_document(self, dstfile):
        with open(dstfile, "w") as fileh:
            fileh.write(self.get_document())


class MindMap2GithubMarkdown(MindMapInterface):
    node = GithubNode

    def get_document(self):
        txt = "\n".join(
            [
                "# TOC",
                self._toc(),
                "",
                "",
                self._body(),
                "",
            ]
        )
        return txt



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Mindmap Interface."""
from typing import Iterable
from bs4 import Tag, BeautifulSoup


class Mindmap(object):
    """Mindmap File Interface."""

    def __init__(self, srcfile):
        with open(srcfile) as fileh:
            content = fileh.read()
        self.content = content
        self.xml = BeautifulSoup(content, "lxml")

    def iternodes(self) -> Iterable[Tag]:
        for obj in self.xml.findAll("node"):
            yield obj



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Test run of script."""
import os
from freeplane_tools.github import MindMap2GithubMarkdown

DIR = os.path.dirname(os.path.abspath(__file__))
TESTFILE = os.path.join(DIR, "template.mm")


def test_bitbucket():
    dfile = os.path.join(DIR, "template.md")
    mm = MindMap2GithubMarkdown(TESTFILE)
    mm.write_document(dfile)


def main():
    """Run main function."""
    test_bitbucket()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
from glob import glob
import pathlib


HERE = pathlib.Path(__file__).parent.resolve()
VERSION = HERE.joinpath("VERSION").read_text().strip()

REQUIRES = HERE.joinpath("requirements.txt").read_text().splitlines()
README = HERE.joinpath("README.md").read_text()

INFO = {
    "name": "Steven Hollingsworth",
    "email": "hollingsworth.stevend@gmail.com",
    "url": "https://github.com/shollingsworth/freeplane_tools",
}

# Can only be one line
SHORT_DESCRTIPTION = "This package provides some tooling around translating freeplane mindmap files into other useful formats"

setup(
    name="freeplane_tools",
    version=VERSION,
    license="MIT",
    description=SHORT_DESCRTIPTION,
    long_description_content_type="text/markdown",
    long_description=README,
    packages=find_packages(),
    install_requires=REQUIRES,
    package_data={
        "": [
            "examples/*",
            "data/*",
        ]
    },
    keywords=[
        "freeplane",
        "mindmap",
        "markdown",
    ],
    scripts=glob("bin/*.py") + glob("bin/*.sh"),
    url=INFO["url"],
    maintainer=INFO["name"],
    maintainer_email=INFO["email"],
    include_package_data=True,
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        "Development Status :: 3 - Alpha",
        # Define that your audience are developers
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        # Again, pick a license
        "License :: OSI Approved :: MIT License",
        # Specify which pyhton versions that you want to support
        "Programming Language :: Python :: 3",
    ],
)
